<?php
// $Id$

/**
 * @file
 * Uses hook_views_data_alter() to add the content_multi_delta_handler_filter object as a possible filter for multigroup fields.
 */

/**
 * Implementation of hook_views_data_alter().
 */
function content_multi_delta_views_data_alter(&$data) {
  //drupal_set_message('<pre>'. print_r($data, TRUE) .'</pre>');
  $field_types = _content_field_types();
  //dpm(content_types());
  $fields = content_fields();
  //dpm($fields);
  foreach ($fields as $field) {
    $table_alias = content_views_tablename($field);
    //dpm($data[$table_alias]);
    // Check that this field's table has data in the $data object.
    if (isset($data[$table_alias])) {
      $db_info = content_database_info($field);
    
      // Fill $types with the content type names which contain this field.
      $types = array();
      foreach (content_types() as $type) {
        if (isset($type['fields'][$field['field_name']])) {
          $types[] = $type['name'];
        }
      }
      
      $db_columns = array();
      $additional_fields = array();
      foreach ($db_info['columns'] as $column => $attributes) {
        // Select explicitly enabled field columns.
        if (!empty($attributes['views'])) {
          $db_columns[$column] = $attributes;
        }
        // Ensure all columns are retrieved.
        $additional_fields[$attributes['column']] = $attributes['column'];
      }
      
      $multigroups = array();
      $multigroup_results = db_query("SELECT cgf.group_name FROM {". fieldgroup_fields_tablename() ."} cgf
                                     INNER JOIN {". fieldgroup_tablename() ."} cg on (cgf.group_name = cg.group_name AND cg.group_type = 'multigroup')
                                     WHERE cgf.field_name = '%s'", $field['field_name']);
      while ($group = db_fetch_array($multigroup_results)) {
        $multigroups[] = $group['group_name'];
      }
      foreach ($multigroups as $group_name) {
        $db_field = $group_name; //'delta'; //TODO: Could this instead be the multigroup name?
        //dpm($field);
        $label_truncated = truncate_utf8(t($field['widget']['label']), 10, TRUE);
        $title = t('@label (!name) - !column', array('@label' => t($field['widget']['label']), '!name' => $field['field_name'], '!column' => $db_field));
        $title_short = t('@label-truncated - !column', array('@label-truncated' => $label_truncated, '!column' => $db_field));
        $data[$table_alias][$db_field] = array(
          'group' => t('Content'),
          'title' => $title,
          'title short' => $title_short,
          'help' =>  t($field_types[$field['type']]['label']) .' - '. t('Appears in: @types', array('@types' => implode(', ', $types))),
        );
        $data[$table_alias][$db_field]['filter'] = array(
          'field' => $db_field,
          'table' => $db_info['table'],
          'handler' => 'content_multi_delta_handler_filter',
          'additional fields' => array($field['field_name'] .'_value' => $field['field_name'] .'_value'),
          'content_field_name' => $field['field_name'],
          'allow empty' => TRUE,
        );
      }
    }
  }
}

/**
 * Implementation of hook_views_handlers().
 */
function content_multi_delta_views_handlers() {
  return array(
    'info' => array(
      'path' => drupal_get_path('module', 'content_multi_delta'), // This isn't necessary unless I put the handler in another dir
    ),
    'handlers' => array(
      'content_multi_delta_handler_filter' => array(
        'parent' => 'views_handler_filter',
      ),
    ),
  );
}