<?php
// $Id$

/**
 * @file
 * Defines a content_multi_delta filter object in views.
 *
 * This filter allows you to associate the deltas in a multigroup so that views doesn't do a cross-join across all values in
 * multivalue cck fields.
 */
class content_multi_delta_handler_filter extends views_handler_filter {
  
  function init(&$view, $options) {
    parent::init($view, $options);
  }
  
  function can_expose() {
    return FALSE;
  }
  
  function options(&$options) {
    parent::options($options);
    $options['content_multi_delta_fields'] = array();
  }
  
  function option_definition() {
    $options = parent::option_definition();
    return $options;
  }
  
  function options_form(&$form, &$form_state) {
    $fields = content_fields();
    $options = array();
    foreach ($fields as $name => $field) {
      // Only need to filter $options to those that are multivalue and on the same node type
      $type_name = $field['type_name'];
      if (($name != $this->definition['content_field_name']) && $this->_is_field_multivalue($name) && $this->_is_field_multigroup($type_name, $name, $this->field)) {
        $table_alias = content_views_tablename($field);
        $options[$table_alias] = $field['widget']['label'];
      }
    }

    $form['content_multi_delta_fields'] = array(
      '#title' => t('Content field(s)'),
      '#type' => 'checkboxes',
      '#options' => $options,
      '#default_value' => $this->options['content_multi_delta_fields'],
      '#multiple' => TRUE,
      '#description' => t('Select fields to filter deltas against.'),
    );
  }
  
  /**
   * Checks to see if a field is listed as multivalue - if the result is '1' then it is.
   */
  function _is_field_multivalue($name) {
    $multivalue = db_result(db_query(
      "SELECT multiple FROM {". content_field_tablename() ."} WHERE field_name = '%s'", $name
    ));
    return ($multivalue == 1); 
  }
  
  /**
   * Checks to see if the field_name is part of a multigroup with the $group_name name.
   */
  function _is_field_multigroup($type_name, $field_name, $group_name) {
    $multigroup = db_result(db_query(
      "SELECT group_type FROM {".
      fieldgroup_fields_tablename()
      ."} cgf INNER JOIN {".
      fieldgroup_tablename()
      ."} cg ON (cgf.group_name = cg.group_name) WHERE cgf.type_name = '%s' AND cgf.field_name = '%s' AND cgf.group_name = '%s'",
      $type_name, $field_name, $group_name
    ));
    return ($multigroup == 'multigroup');
  }
  
  function options_submit(&$form, &$form_state) {
    $option_tables = array();
    foreach ($form_state['values']['options']['content_multi_delta_fields'] as $table => $value) {
      if (!empty($value)) {
        $option_tables[] = $table; 
      }
    }
    $form_state['values']['options']['content_multi_delta_fields'] = $option_tables;
  }
  
  function query() {
    $this->ensure_my_table();
    foreach ($this->options['content_multi_delta_fields'] as $option_table) {
      $this->query->add_where($this->options['group'], "$this->table_alias.delta = %s.delta", $option_table);
    }
  }
}